Module boxed

Module boxed 

This module contains the Box smart pointer, capable of managing memory in a IndexAllocator.

Structs

Box
A smart pointer holding its value in an IndexAllocator and managing its memory.