This module contains the Box smart pointer, capable of managing memory in a IndexAllocator.
Structs
- Box
- A smart pointer holding its value in an
IndexAllocatorand managing its memory.
This module contains the Box smart pointer, capable of managing memory in a IndexAllocator.
IndexAllocator and managing its memory.